@@ -6,7 +6,8 @@
 #===============================================================================
 package WebDAO::Modal;
 our $VERSION = '0.01';
-
+use strict;
+use warnings;
 1;
 
 
